/*
 * Copyright (C) 2015 by Multi-Tech Systems
 *
 * This file is part of libmts.
 *
 * libmts is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * libmts is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with libmts.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

/*! \file   MTS_Object.h
 \brief  An object
 \date   28MAR12
 \author Sean Godinez

 A common base class to handle objects.
 */
#ifndef _MTS_OBJECT_H_
#define _MTS_OBJECT_H_

#include <mts/MTS_Buffer.h>
#include <ostream>
#include <string>
#include <set>

namespace MTS {

    //! An object
    /*!
     A common base class to handle objects

     \sa Buffer
     */
    class Object {

        public:
            virtual ~Object();                             //!< Destructs object

            virtual void encode(Buffer& buffer) const = 0; //!< Encodes object into byte buffer
            virtual void decode(Buffer& buffer) = 0; //!< Decodes object from byte buffer
            virtual void copy(const Object& object) = 0; //!< Copies another object
            virtual Object* clone() const = 0;                //!< Clones object

            virtual std::string toString() const; //!< Generates a string of the object
            virtual std::string toIDD() const; //!< Generates a string of the object type id

        protected:
            Object();                                 //!< Constructor of object
    };
}

#endif
