/*
 * Copyright (C) 2015 by Multi-Tech Systems
 *
 * This file is part of libmts.
 *
 * libmts is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * libmts is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with libmts.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

/*! \file   MTS_System.h
 \brief  System Utilities
 \date   15JUN11
 \author Sean Godinez

 System utilities for time, endian, etc.
 */
#ifndef MTS_SYSTEM_H
#define MTS_SYSTEM_H

#include <mts/MTS_NonConstructable.h>
#include <mts/MTS_Stdint.h>
#include <string>

namespace MTS {

    class System: private NonConstructable {

        public:

            //UTC (Coordinated Universal Time) : This is the standard international time or the Greenwich Mean Time.
            //EPOCH : number of seconds elapsed since 00:00:00 on January 1, 1970, Coordinated Universal Time.

            static uint64_t timeMicros();
            static uint64_t precisionTimeMicros();

            static bool isBigEndian();
            static void swapBytes(uint8_t* const pBuffer, const uint32_t iSize);

            static int32_t cmd(const std::string& cmd, std::string& result);
            static int32_t readFile(const std::string& path, std::string& result);
    };
}

#endif
