/*
 * Copyright (C) 2015 by Multi-Tech Systems
 *
 * This file is part of libmts.
 *
 * libmts is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * libmts is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with libmts.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

/*! 
 \file MTS_Timer.h
 \brief Tracks passage of time
 \date Jan 3, 2014
 \author sgodinez

 Useful for tracking time and timeout loops
 */

#ifndef MTS_TIMER_H_
#define MTS_TIMER_H_

#include <mts/MTS_Stdint.h>

namespace MTS {

    class Timer {

        public:
            Timer();
            virtual ~Timer();

            void start();
            void stop();
            void pause();
            void resume();
            void reset();

            bool isRunning();

            uint64_t getMicros();
            uint64_t getMillis();
            uint64_t getSeconds();
            uint64_t getMinutes();

        protected:

        private:
            uint64_t m_iStart;
            uint64_t m_iPause;
            bool m_bStarted;
            bool m_bPaused;
    };
}

#endif /* MTS_TIMER_H_ */
