#include "Test_MTS_Text.h"
#include <mts/MTS_Logger.h>
#include <sstream>

CPPUNIT_TEST_SUITE_REGISTRATION(Test_MTS_Text);

void Test_MTS_Text::testText__datetimeIsBefore() {
    CPPUNIT_ASSERT(MTS::Text::datetimeIsBefore("08/10/12 12:00:00", "08/10/12 12:00:01"));
    CPPUNIT_ASSERT(!MTS::Text::datetimeIsBefore("08/10/12 12:00:01", "08/10/12 12:00:00"));
    CPPUNIT_ASSERT(MTS::Text::datetimeIsBefore("08/10/10 12:00:00", "08/10/12 12:00:00"));
    CPPUNIT_ASSERT(MTS::Text::datetimeIsBefore("08/09/12 12:00:00", "08/10/12 12:00:01"));
}

void Test_MTS_Text::testis_base64() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testbase64_encode() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testbase64_decode() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__time() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__date() {
    std::string sZero("Thu, 01 Jan 1970 00:00:02 GMT");

    std::string sDate;
    time_t iTime = 2;
    tm* pTime = gmtime(&iTime);

    sDate = MTS::Text::date(*pTime, MTS::Text::DATEFORMAT::RFC_1123);
    printDebug("MTS::Text::date [%s]", sDate.c_str());
    CPPUNIT_ASSERT(sZero == sDate);
}

void Test_MTS_Text::testText__split() {
    std::string test = ",test";
    std::vector<std::string> list = MTS::Text::split(test, ",");

    CPPUNIT_ASSERT(list.size() == 2);
    CPPUNIT_ASSERT(list[0] == "");
    CPPUNIT_ASSERT(list[1] == "test");
}

void Test_MTS_Text::testText__split_limit() {
    std::string path = "stats";
    std::vector<std::string> parts = MTS::Text::split(path, '/', 3);
    CPPUNIT_ASSERT(parts.size() == 1);
    CPPUNIT_ASSERT(parts[0] == "stats");

    std::string path1 = "stats/radio";
    std::vector<std::string> parts1 = MTS::Text::split(path1, '/', 3);
    CPPUNIT_ASSERT(parts1.size() == 2);
    CPPUNIT_ASSERT(parts1[0] == "stats");
    CPPUNIT_ASSERT(parts1[1] == "radio");

    std::string path2 = "stats/radio/debug/hardware";
    std::vector<std::string> parts2 = MTS::Text::split(path2, '/');
    CPPUNIT_ASSERT(parts2.size() == 4);
    CPPUNIT_ASSERT(parts2[0] == "stats");
    CPPUNIT_ASSERT(parts2[1] == "radio");
    CPPUNIT_ASSERT(parts2[2] == "debug");
    CPPUNIT_ASSERT(parts2[3] == "hardware");

    std::string path3 = "stats/radio/debug/hardware";
    std::vector<std::string> parts3 = MTS::Text::split(path3, '/', -2);
    CPPUNIT_ASSERT(parts3.size() == 4);
    CPPUNIT_ASSERT(parts3[0] == "stats");
    CPPUNIT_ASSERT(parts3[1] == "radio");
    CPPUNIT_ASSERT(parts3[2] == "debug");
}

void Test_MTS_Text::testText__split_values() {
    std::string path = "stats/radio/debug";
    std::vector<std::string> parts = MTS::Text::split(path, '/', 3);
    CPPUNIT_ASSERT(parts.size() == 3);
    CPPUNIT_ASSERT(parts[0] == "stats");
    CPPUNIT_ASSERT(parts[1] == "radio");
    CPPUNIT_ASSERT(parts[2] == "debug");

    std::string path1 = "stats/radio/debug/hardware";
    std::vector<std::string> parts1 = MTS::Text::split(path1, '/', 3);
    CPPUNIT_ASSERT(parts1.size() == 3);
    CPPUNIT_ASSERT(parts1[0] == "stats");
    CPPUNIT_ASSERT(parts1[1] == "radio");
    CPPUNIT_ASSERT(parts1[2] == "debug/hardware");

    std::string path2 = "stats/radio/debug/hardware";
    std::vector<std::string> parts2 = MTS::Text::split(path2, '/', 2);
    CPPUNIT_ASSERT(parts2.size() == 2);
    CPPUNIT_ASSERT(parts2[0] == "stats");
    CPPUNIT_ASSERT(parts2[1] == "radio/debug/hardware");
}

void Test_MTS_Text::testText__getLine() {

	std::string line1("-----------------------------13456055954665194976790380");
	std::string line2("Content-Disposition: form-data; name=\"archivo\"; filename=\"test\"");
	std::string line3("Content-Type: application/octet-stream");
	std::string line4("");
	std::string line5("**HELLOWORLD**");
	std::string line6("");
	std::string line7("-----------------------------13456055954665194976790380--");

	std::stringstream ss;
	ss << line1 << "\n";
	ss << line2 << "\n\r";
	ss << line3 << "\n";
	ss << line4 << "\r\n";
	ss << line5 << "\n";
	ss << line6 << "\n";
	ss << line7 << "\n";

	std::string test(ss.str());

	size_t pos = 0;
	CPPUNIT_ASSERT(line1 == MTS::Text::getLine(test, pos, pos));
	CPPUNIT_ASSERT(line2 == MTS::Text::getLine(test, pos, pos));
	CPPUNIT_ASSERT(line3 == MTS::Text::getLine(test, pos, pos));
	CPPUNIT_ASSERT(line4 == MTS::Text::getLine(test, pos, pos));
	CPPUNIT_ASSERT(line5 == MTS::Text::getLine(test, pos, pos));
	CPPUNIT_ASSERT(line6 == MTS::Text::getLine(test, pos, pos));
	CPPUNIT_ASSERT(line7 == MTS::Text::getLine(test, pos, pos));
	CPPUNIT_ASSERT("" == MTS::Text::getLine(test, pos, pos));

}

void Test_MTS_Text::testText__trim() {
    std::string test = " test ";
    std::string result = MTS::Text::trim(test);
    //std::printf("(%s)\n", result.c_str());
    CPPUNIT_ASSERT(result == "test");

    test = "test";
    result = MTS::Text::trim(test);
    //std::printf("before: (%s) after: (%s)\n", test.c_str(), result.c_str());
    CPPUNIT_ASSERT(result == "test");

    test = "test\t\t";
    result = MTS::Text::trim(test);
    //std::printf("before: (%s) after: (%s)\n", test.c_str(), result.c_str());
    CPPUNIT_ASSERT(result == "test");

    test = "\t\ttest";
    result = MTS::Text::trim(test);
    //std::printf("before: (%s) after: (%s)\n", test.c_str(), result.c_str());
    CPPUNIT_ASSERT(result == "test");

    test = "\ttest\t";
    result = MTS::Text::trim(test);
    //std::printf("before: (%s) after: (%s)\n", test.c_str(), result.c_str());
    CPPUNIT_ASSERT(result == "test");

    test = "\n\nte  st\n\n";
    result = MTS::Text::trim(test);
    //std::printf("before: (%s) after: (%s)\n", test.c_str(), result.c_str());
    CPPUNIT_ASSERT(result == "te  st");

    test = "\n\ntest\n\n";
    result = MTS::Text::trim(test);
    //std::printf("before: (%s) after: (%s)\n", test.c_str(), result.c_str());
    CPPUNIT_ASSERT(result == "test");

    test = "\n\rtest\n\r";
    result = MTS::Text::trim(test);
    //std::printf("before: (%s) after: (%s)\n", test.c_str(), result.c_str());
    CPPUNIT_ASSERT(result == "test");

    test = "test\n\r";
    result = MTS::Text::trim(test);
    //std::printf("before: (%s) after: (%s)\n", test.c_str(), result.c_str());
    CPPUNIT_ASSERT(result == "test");

    test = "\r\n\n\rtest\r\n\r\r\n\n\r\n";
    result = MTS::Text::trim(test);
    //std::printf("before: (%s) after: (%s)\n", test.c_str(), result.c_str());
    CPPUNIT_ASSERT(result == "test");

    test = "    ";
    result = MTS::Text::trim(test);
    CPPUNIT_ASSERT(result == "");
}


void Test_MTS_Text::testText__strip() {
    std::string phonenum = "(763) 785-3500";
    std::string hw = "H*E*L*L*O WORLD!";
    std::string result;
    std::vector<uint8_t> vElements;

    vElements.push_back('(');
    vElements.push_back(')');
    vElements.push_back(' ');
    vElements.push_back('-');

    result = MTS::Text::strip(phonenum, vElements);
    CPPUNIT_ASSERT(result == "7637853500");

    result = MTS::Text::strip(hw, '*');
    CPPUNIT_ASSERT(result == "HELLO WORLD!");
}


void Test_MTS_Text::testText__toLowerCase() {
    std::string test = "TeSt";
    CPPUNIT_ASSERT(MTS::Text::toLowerCase(test) == "test");
}

void Test_MTS_Text::testText__toUpperCase() {
    std::string test = "TeSt";
    CPPUNIT_ASSERT(MTS::Text::toUpperCase(test) == "TEST");
}

void Test_MTS_Text::testText__toCapitalized() {
    std::string test = "test";
    CPPUNIT_ASSERT(MTS::Text::toCapitalized(test) == "Test");
    test = "TEST\0";
    CPPUNIT_ASSERT(MTS::Text::toCapitalized(test) == "Test");
    test = "\0";
    CPPUNIT_ASSERT(MTS::Text::toCapitalized(test) == "");
    test = "a\0";
    printDebug("[%s] [%s]", test.c_str(), MTS::Text::toCapitalized(test).c_str());
    CPPUNIT_ASSERT(MTS::Text::toCapitalized(test) == "A");
}

void Test_MTS_Text::testText__toCamelCase() {
	std::string test("Hello World");
	CPPUNIT_ASSERT(MTS::Text::toCamelCase(test) == "helloWorld");
}

void Test_MTS_Text::testText__toBase64() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__toBase64_1() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__fromBase64() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__widen() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__narrow() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__format() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__format_1() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__format_2() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__format_3() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__format_4() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__format_5() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__format_6() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__format_7() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__format_8() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__format_9() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testtoHexString() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__formatHex() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__formatHex_1() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__formatHex_2() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__formatHex_3() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__formatHex_4() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__formatHex_5() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__formatHex_6() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__formatHex_7() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__formatHex_8() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__parse() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__parse_1() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__parse_2() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__parse_3() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__parse_4() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__parse_5() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__parse_6() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__parse_7() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__parse_8() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__parse_9() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__parseHex() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__parseHex_1() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__parseHex_2() {
    CPPUNIT_ASSERT(false);
}

void Test_MTS_Text::testText__parseHex_3() {
    CPPUNIT_ASSERT(false);
}

